#!/bin/sh

# PTF/Efix Installer Driver Script

Edition=aes
PTFNUM=ptf_3
PTFDescription="IBM WebSphere Application Server V4.0.3 AEs Fixpack"


ScriptVersion="1.35.1.45"
ScriptUpdate="4/16/02"

OS_NAME=`uname`
export OS_NAME

echo 
echo Installation Program
echo  

checkLicense() {

echo "FixPak License:
        The software samples, tools, updates, fixes and other materials (\"Code\")
        available in this archive for WebSphere Application Server (\"Program\")
        are copyrighted materials. By typing \"Accept\", you agree that the Code
        is provided under, and is subject to, the terms and conditions of the
        license agreement(s) which accompanied or were contained in the copy or
        copies of the Program for which you are obtaining the Code. You are not
        authorized to install or use the Code except as part of a Program for which
        you have a valid Prooof of Entitlement or other authorization as specified
        in such license agreement(s). You further agree that you will comply with all
        applicable laws and export regulations. [Accept/Reject]"

    read lresp
    if [ "$lresp" = "Accept" -o "$lresp" = "accept" ]; then
        echo "Proceeding with the install process"
    else
        echo "Install will not continue without Accepting License Agreement"
        Egress
    fi;
}


testTools() {
    echo "Testing availability of update tools."

    if [ -f "LogEvent.sh" ]; then
        echo The Logging tool [LogEvent.sh] is available.
      else 
        echo "ERROR: No Logging tool [LogEvent.sh] is available.\n\n"
        echo "Halting the PTF update.\n\n"
        EgressWithError
    fi;
}

#Make sure that the temporary directory is usable.

forceTmp() {
    if [ -z "$TMP" ]; then 
        echo No temporary directory is set in the environment 'TMP'.
        echo The current directory will be used.
        echo 
        TMP=$PWD
    else
        echo Noted temporary directory from in the environment 'TMP':
        echo $TMP
    fi;
}

testTmp() {
    echo Testing that the temporary directory is writable.
    echo "Test to see if the TMP dir is writable" > $TMP/header.tmp >/dev/null 2>&1
    if [ $? != 0 ]; then
        echo ERROR: The temporary directory is not writable.
        echo
        echo "Halting the PTF update.\n\n"
        EgressWithError
    else
        rm $TMP/header.tmp
        echo The temporary directory is writable.
        echo
    fi;
}

writeSummaryHeader() {
    STARTTIME=`date +"%Y-%m-%d-%H:%M:%S"`

    SUMMARYBASE=Summary_${PTFNUM}_$STARTTIME.log
    SummaryLog=$TMP/$SUMMARYBASE
    export SummaryLog
    echo Using summary log: $SummaryLog\n

    ./LogEvent.sh echo "\n
        $PTFDescription\n
        PTF Number: $PTFNUM\n
        TimeStamp: $STARTTIME\n
        Script Version: $ScriptVersion\n
        Script Update: $ScriptUpdate\n "
}

initOS() {
    # Set variables based on OS name
    ./LogEvent.sh echo "Perform platform specific initialization\n"

    case "$OS_NAME" in
    AIX)
        DEFAULT_IHS_DIR=/usr/HTTPServer
	DEFAULT_WAS_DIR=/usr/WebSphere/AppServer
        PLUGIN_FILE=bin/mod_app_server_http.so  
    ;;
    SunOS|Solaris)
        DEFAULT_IHS_DIR=/opt/IBMHTTPD
        DEFAULT_WAS_DIR=/opt/WebSphere/AppServer
        PLUGIN_FILE=bin/mod_app_server_http.so
    ;;
    HP-UX)
        DEFAULT_IHS_DIR=/opt/HTTPServer
        DEFAULT_WAS_DIR=/opt/WebSphere/AppServer
        PLUGIN_FILE=bin/mod_app_server_http.sl
    ;;
    Linux)
        DEFAULT_IHS_DIR=/opt/IBMHTTPServer
        DEFAULT_WAS_DIR=/opt/WebSphere/AppServer
        PLUGIN_FILE=bin/mod_app_server_http.so

        # Need to document what LD_ASSUME_KERNAL is for.
        LD_ASSUME_KERNEL=2.2.5
        export LD_ASSUME_KERNEL
    ;;
    *)
        ./LogEvent.sh echo "ERROR: Unspported platform: $OS_NAME"
        ./LogEvent.sh echo "Halting the PTF update.\n\n"
        completedWithError
    ;;
    esac
}

usageBadParm() {
    ./LogEvent.sh echo "ERROR: The command line parameter $1 is invalid.\n\n"
    ./LogEvent.sh echo "Use -usage to see the available command line options.\n\n"
    ./LogEvent.sh echo "Use -help to see comprehensive help.\n\n"
    exit 1
}

parseOptions() {
    ./LogEvent.sh echolog Parsing command line options:

    # 'SILENT' controls if this is a silent install.
    #
    # 'HELP' controls if help has been requested.
    # 'USAGE' controls is usage has been requsted.
    #
    # 'FORCEJ2C' controls if the JTC connector is to be installed.
    #
    # 'OVERWRITEBUJ' controls if backup jar's may be overwritten.
    # The possible values are blank or '-OverWriteBackupJar'.

    SILENT=false

    if [ -z "$FORCEJ2C" ]; then
        FORCEJ2C=false
    fi;

    OVERWRITEBUJ=

    # Cycle through the parameters until an invalid option is parsed, or
    # all of the parameters are exhausted, or one of the help options
    # is presented.

    while [ $# -ge 1 ]; do
    case $1 in 

    -silent|-Silent)
            SILENT=true
    ;;
        -Connector )
            FORCEJ2C=true
    ;;
        Usage|usage)
            usage
    ;;
        -Usage|-usage|-?)
            usage
    ;;
        Help|help)
            help
    ;;
        -Help|-help)
            help
    ;;
    *) ./LogEvent.sh echo ""
       usageBadParm;;
    esac
        shift;
        done

    completeParse
}


completeParse() {
    ./LogEvent.sh echolog "Completed parsing command line options.\n\n"

    if [ "$SILENT" = "true" ]; then
        OverWriteBUJ=-OverWriteBackupJar
      fi;

    displayOptions
    displayEnvironment
}

usage() {
    echo Usage: install.sh [ -options ]
    echo
    echo This script performs the update for $PTFNUM of the WebSphere Application Server.
    echo
    echo Valid command line options include:
    echo "   -Silent     [ Enable silent mode ]"
    echo "   -Connector  [ Force the installation of J2C Connector Technology ]"
    echo
    echo A number of options are available through environment variables, as follows:
    echo
    echo "    SKIP_WAS = true | false "
    echo "    WAS_UPDATE_HOME = [path]"
    echo
    echo "    SKIP_JDK =  true | false "
    echo "    JDK_UPDATE_HOME = [path]"    
    echo
    echo "    INSTALL_IHS =  true | false "
    echo "    IHS_UPDATE_HOME = [path]"
    echo
    echo "    FORCEJ2C =  true | false "
    echo
    echo "    BACKUP_DIR = [path]"
    echo "    LOGS_DIR = [path]"
    echo
    echo "    TMP = [path]"
    echo
    echo "    IPLANET_HOME = [path]"
    echo 
    echo "    IPLANET_VERSION = 4 | 6 "
    echo

    exit 0
}

help() {    
    echo 
    echo Use SKIP_WAS to disable the update the the WebSphere Application Server.
    echo In silent mode the Application Server is updated by default.
    echo 
    echo Use WAS_UPDATE_HOME to specify the home for the Application Server.  In
    echo silent mode, unless the Application Server update is disabled, the
    echo Application Server home must be specified.
    echo 
    echo Use SKIP_JDK to disable the update of the Java Development Kit.
    echo In silent mode, if available, the JDK will be updated by default.
    echo 
    echo Use JDK_UPDATE_HOME to specify the home for the Java Development Kit.
    echo Normally, the JDK home will be computed relative to the Application
    echo Server home.
    echo 
    echo Also use JDK_UPDATE_HOME to specify the location of the Java Development
    echo Kit which is being used to run the update programs.  In silent mode, if
    echo the Application Server update is disabled, or if no Java Development Kit
    echo is available beneath the Application Server Home, the JDK home must be
    echo specified to allow the update programs to run.
    echo 
    echo Use INSTALL_IHS to enable the update of the IBM HTTP Server.  In silent
    echo mode, by default, the IBM HTTP Server is not updated.
    echo 
    echo Use IHS_UPDATE_HOME to specify the home of the IBM HTTP Server.  In
    echo silent mode, when the IBM HTTP Server update is enabled, a home for the
    echo IBM HTTP Server must be provided.
    echo 
    echo Use FORCEJ2C to force the J2C connector technology to be installed.
    echo The WebSphere Application Server must be being updated and the
    echo Application Server JDK must be in use for a J2C connector technology
    echo update to be applicable.
    echo 
    echo When the WebSphere Application Server is being updated and the
    echo Application Server JDK is in use, if the J2C connector technology
    echo Java Archive JAR file is installed, the J2C update will
    echo automatically be applied.  In silent mode, if the J2C jar file is
    echo not available, the J2C update, acting as an installation, will be
    echo performed only if the FORCEJ2C command line option is specified,
    echo or the FORCEJ2C environment variable is set to true.
    echo 
    echo Use BACKUP_DIR to specify the location into which to put backup
    echo files for the selected updates.  In silent mode, when a backup
    echo directory is not specified, backup files are placed into the
    echo first of the following locations which is writable:
    echo 
    echo    The Application Server Home
    echo    The Current Directory
    echo    The Temporary Directory
    echo 
    echo Use LOGS_DIR to specify the location into which to put log files,
    echo including both the summary log file and log files for the selected
    echo updates.  In silent mode, when a logs directory is not specified,
    echo log files are placed in the first of the following locations which
    echo are writable:
    echo 
    echo     The Application Server Home
    echo     The Current Directory
    echo     The Temporary Directory
    echo 
    echo The summary log is initially written to the temporary directory.
    echo After the selected updates are performed the summary log is copied
    echo into the logs directory.
    echo
    echo Use IPLANET_HOME to specify the location of the config directory for
    echo the iPlanet web server.  An example IPLANET_HOME would be:
    echo '/usr/iplanet/servers/https-<hostname>/config'.
    echo
    echo Use IPLANET_VERSION to specify the version of iPlanet that the user
    echo would like to update.  There are only two valid values for IPLANET_VERSION
    echo and they are 4 and 6.
    echo 

    exit 0
}
    
displayOptions() {
    ./LogEvent.sh echo " \n
        Options Selected: \n \n
        Silent: $SILENT \n
        ForceJ2C: $FORCEJ2C \n\n"
}

displayEnvironment() {
    ./LogEvent.sh echolog "Environment Settings:\n
        Skip Application Server Update 'SKIP_WAS':\n
    [ $SKIP_WAS ] \n
        Application Server Home 'WAS_UPDATE_HOME':\n
    [ $WAS_UPDATE_HOME ] \n\n
        Skip Java Development Kit Update 'SKIP_JDK':\n
    [ $SKIP_JDK ] \n
        Java Development Kit Home 'JDK_UPDATE_HOME':\n
    [ $JDK_UPDATE_HOME ] \n\n
        Force IBM HTTP Server Update 'INSTALL_IHS':\n
    [ $INSTALL_IHS ] \n
        IBM HTTP Server Home 'IHS_UPDATE_HOME':\n
    [ $IHS_UPDATE_HOME ]\n\n
        Backup Path 'BACKUP_DIR':\n
    [ $BACKUP_DIR ]\n\n
        Log Path 'LOGS_DIR':
    [ $LOGS_DIR ]\n\n
        Temporary Directory 'TMP':\n
    [ $TMP ]\n\n
        iPlanet web server configuration home 'IPLANET_HOME':\n
    [ $IPLANET_HOME ]\n\n
        iPlanet web server version 'IPLANET_VERSION':\n
    [ $IPLANET_VERSION ]\n\n"

}

completedWithError() {
    ./LogEvent.sh echo "Halting the PTF update.\n\n"

    ./LogEvent.sh echo "A log of installation activity may be found in the summary log file:\n
        $SummaryLog\n\n"

    EgressWithError
}

copyLog() {
    if [ -n "$LEAVE_LOG" -a "$LOGS_DIR" != "$TMP" ]; then
        OLD_SUMMARYLOG=$SummaryLog
        NEW_SUMMARYLOG=$LOGS_DIR/$SUMMARYBASE
        ./LogEvent.sh cp $OLD_SUMMARYLOG $NEW_SUMMARYLOG
        
        if [ $? -eq 0 ]; then
            SummaryLog=$NEW_SUMMARYLOG
        else
            ./LogEvent.sh echo "An error occurred while copying the summary log.\n\n
                A log of installation activity may be found in the summary log file:\n
                $SummaryLog\n\n"

            EgressWithError
        fi;
    fi;
}

completeInstall() {
    ./LogEvent.sh echo "$PTFDescription install complete.\n\n"

    copyLog

    ./LogEvent.sh echo "A log of installation activity may be found in the summary log file:\n
        $SummaryLog\n\n"

    if [ "$OS_NAME" = "AIX" ]; then
        ./LogEvent.sh slibclean
    fi;

    Egress
}

EgressWithError() {
    exit 1
}

Egress() {
    exit 0
}

GetInput() {
    if [ "$1" = "YorN" ]; then
        while true
        do
            ./LogEvent.sh echo "$2"
            read resp
            if [ "$resp" = "Yes" -o "$resp" = "y" -o "$resp" = "yes" -o "$resp" = "Y" ]; then
                YorN=yes
                ./LogEvent.sh echolog "User requested $resp"
                break;
            elif [ "$resp" = "No" -o "$resp" = "n" -o "$resp" = "no" -o "$resp" = "N" ]; then
                YorN=no
                ./LogEvent.sh echolog "User requested $resp"
                break;
            else
                echo "Invalid response.\n Please enter \"yes\" or \"no\" "
                continue;
            fi;
        done
    else 
        while true
        do
            ./LogEvent.sh echo "$2"
            read resp
            if [ "$1" = "Default" ]; then
                if [ -z "$resp" ]; then
                    VAR=$3
                    ./LogEvent.sh echo "Using the Default Value [$3]"
                    break;
                fi;
            fi;
            if [ -n "$resp" ]; then
                VAR="$resp"
                ./LogEvent.sh echolog "User requested $resp"
                break;
            fi;
        done
    fi;
} 

checkUpdateJars() {
    if [ ! -f "was40_${Edition}_$PTFNUM.jar" ]; then
        ./LogEvent.sh echo "WAS Update jar file is missing in this FixPack."
         completedWithError    
    fi;

    if [ ! -f "jdk_$PTFNUM.jar" ]; then
        ./LogEvent.sh echo "JDK Update jar file is missing in this FixPack."
         completedWithError    
    fi;

    if [ ! -f "ihs_$PTFNUM.jar" ]; then
        ./LogEvent.sh echo "IHS Update jar file is missing in this FixPack."
        completedWithError    
    fi;
}

checkUpdateWas() {
    # Section for handling detection of the application server update.
    #
    # Inputs/Outputs:
    #     SKIP_WAS
    #     WAS_UPDATE_HOME

    echo
    echo $PTFDescription
    echo "\n\n**********************************************"
    echo "IMPORTANT NOTE:\n"
    echo "Please shut down the Application Server, AAT and "
    echo " any WebServers that might be running."
    echo "If not the PTF may not be installed properly.\n"
    echo "***************************************************\n"
    echo

    ./LogEvent.sh echo "Checking Application Server update.\n"

    PRODUCT_FILE=properties/com/ibm/websphere/product.xml
    PROPERTIES_FILE=deploytool/itp/install/install.properties
    # NOTE: PLUGIN_FILE is also a signature file and it's set depending on OS (set above)

    if [ "$SKIP_WAS" = "" ]; then
        SKIP_WAS=false
    fi;

    if [ "$SKIP_WAS" = "true" ]; then
        ./LogEvent.sh echo "The Application Server update was disabled from the environment.\n"

    elif [ "$SILENT" = "false" ]; then
        GetInput "YorN" "Update the Application Server? [y/n]"
        if [ "$YorN" = "no" ]; then
            ./LogEvent.sh echo "The Application Server update was disabled by the user.\n"
            SKIP_WAS=true
        else
            ./LogEvent.sh echo "The Application Server update was enabled by the user.\n"

            ORIG_WAS_HOME=$WAS_UPDATE_HOME

            while true
            do
                READ_WAS_HOME=false
                WAS_UPDATE_HOME=$ORIG_WAS_HOME

                if [ "$WAS_UPDATE_HOME" = "" ]; then
                    ./LogEvent.sh echo "No Application Server home was specified in the environment ['WAS_UPDATE_HOME'].\n"
                    READ_WAS_HOME=true
                else
                    ./LogEvent.sh echo "An application server home is available from the environment:\n
                        $WAS_UPDATE_HOME\n\n"

                    GetInput "YorN" "Accept the Application Server Home from the environment? [y/n]"
                    if [ "$YorN" = "no" ]; then
                        READ_WAS_HOME=true
                    fi
                fi

                if [ "$READ_WAS_HOME" = "true" ]; then
                    GetInput Default "Enter the Application Server Home:[$DEFAULT_WAS_DIR]" "$DEFAULT_WAS_DIR"
                    WAS_UPDATE_HOME=$VAR
                fi

                if [ -f "$WAS_UPDATE_HOME/$PRODUCT_FILE" ]; then
                    ./LogEvent.sh echo "The Application Server Home contains a product file:\n
                        $WAS_UPDATE_HOME/$PRODUCT_FILE\n\n"
                    break;
                else
                     if [ -f "$WAS_UPDATE_HOME/$PROPERTIES_FILE" ]; then
	                ./LogEvent.sh echo "Detected Tools Only install"
	                ./LogEvent.sh echo "The Application Server Home contains a properties file:\n
       	                $WAS_UPDATE_HOME/$PROPERTIES_FILE\n\n"
       	                break;
                     elif [ -f "$WAS_UPDATE_HOME/$PLUGIN_FILE" ]; then
	                 ./LogEvent.sh echo "Detected Plugin Only install"
	                 ./LogEvent.sh echo "The Application Server Home contains a plugin file:\n
       	                   $WAS_UPDATE_HOME/$PLUGIN_FILE\n\n"
       	                   break;
	             fi;

		     ./LogEvent.sh echo "ERROR: The specified Application Server Home cannot be used:\n
                     Neither the signature product file, the signature properties file\n
                     nor the signature plugin file could be found under the specified directory.\n
                     The following path was used to search for the signature product file:\n
                     [ $WAS_UPDATE_HOME/$PRODUCT_FILE ]\n
                     The following path was used to search for the signature properties file:\n
                     [ $WAS_UPDATE_HOME/$PROPERTIES_FILE ]\n
                     The following path was used to search for the signature plugin file:\n
                     [ $WAS_UPDATE_HOME/$PLUGIN_FILE ]\n\n"
                  

                    GetInput "YorN" "Cancel this update? [y/n]"
                    if [ "$YorN" = "yes" ]; then
                        completedWithError
                    fi
                fi
            done
        fi
    else
        ./LogEvent.sh echo "Silent Mode: The Application Server update is enabled.\n"

        if [ "$WAS_UPDATE_HOME" = "" ]; then
            ./LogEvent.sh echo "ERROR: The Application Server update is enabled, but\n
                no Application Server Home ['WAS_UPDATE_HOME'] value was set.\n\n"
            usage
            completedWithError
        else
            ./LogEvent.sh echo "The value for Application Server home ['WAS_UPDATE_HOME'] is set.\n\n"

            if [ -f "$WAS_UPDATE_HOME/$PRODUCT_FILE" ]; then
               ./LogEvent.sh echo "The Application Server home has a product file:\n
               $WAS_UPDATE_HOME/$PRODUCT_FILE\n\n"
            elif [ -f "$WAS_UPDATE_HOME/$PROPERTIES_FILE" ]; then
	       ./LogEvent.sh echo "Detected Tools Only install"
	       ./LogEvent.sh echo "The Application Server Home contains a properties file:\n
       	       $WAS_UPDATE_HOME/$PROPERTIES_FILE\n\n"
            elif [ -f "$WAS_UPDATE_HOME/$PLUGIN_FILE" ]; then
	       ./LogEvent.sh echo "Detected Plugin Only install"
	       ./LogEvent.sh echo "The Application Server Home contains a plugin file:\n
       	       $WAS_UPDATE_HOME/$PLUGIN_FILE\n\n"
            else
	        ./LogEvent.sh echo "ERROR: The specified Application Server Home cannot be used:\n
                        Neither the signature product file nor the signature properties files\n
                        could be found under the specified directory.\n
                        The following path was used to search for the signature product file:\n
                        [ $WAS_UPDATE_HOME/$PRODUCT_FILE ]\n
                        The following path was used to search for the signature properties file:\n
                        [ $WAS_UPDATE_HOME/$PROPERTIES_FILE ]\n
                        The following path was used to search for the signature plugin file:\n
                        [ $WAS_UPDATE_HOME/$PLUGIN_FILE ]\n\n"
                completedWithError
            fi
        fi
    fi
}

checkJDK() {
    # Section for handling detection of JDK update.
    #

    # Inputs:
    #     SILENT
    #     INSTALL_APP_SERVER
    #     SKIP_JDK
    #     JDK_UPDATE_HOME
    #
    # Outputs:
    #     SKIP_JDK
    #     JDK_UPDATE_HOME
    #     IS_WAS_JDK

    ./LogEvent.sh echo "Locating JDK, and checking for JDK update.\n\n"

    JAVA_SUB_PATH=jre/bin/java

    if [ "$SKIP_JDK" = "" ]; then
        SKIP_JDK=false
    fi

    JDK_FROM_WAS=
    IS_WAS_JDK=false

    ./LogEvent.sh echo "Looking for an Application Server JDK.\n\n"

    if [ "$SKIP_WAS" = "true" ]; then
        ./LogEvent.sh echo "The Application Server is not being updated; skipping the\n
            search for the Application Server JDK.\n\n"
    else
        ./LogEvent.sh echo "The Application Server is being updated; searching for the\n
            Application Server JDK.\n\n"

        if [ -f "$WAS_UPDATE_HOME/java/$JAVA_SUB_PATH" ]; then
            ./LogEvent.sh echo "Located $JAVA_SUB_PATH beneath $WAS_UPDATE_HOME/java.\n\n
                The Application Server JDK is available for use.\n\n"
            JDK_FROM_WAS=$WAS_UPDATE_HOME/java
        else
                ./LogEvent.sh echo "Cannot find $JAVA_SUB_PATH beneath $WAS_UPDATE_HOME/java.\n\n
                    The Application Server JDK cannot be used.\n\n"
        fi
    fi

    ./LogEvent.sh echo "Determining the JDK for use.\n\n
        Note that a JDK must be available for performing updates,\n
        even if the JDK is not being updated.\n\n"

    if [ "$SILENT" = "true" ]; then
        if [ "$JDK_UPDATE_HOME" != "" ]; then
            ./LogEvent.sh echo "A JDK is available from the environment:\n
                $JDK_UPDATE_HOME\n\n"
        
            if [ -f "$JDK_UPDATE_HOME/$JAVA_SUB_PATH" ]; then
                ./LogEvent.sh echo "$JDK_UPDATE_HOME does have $JAVA_SUB_PATH.\n\n
                    Accepting the JDK from the environment.\n\n"
            	if [ "$JDK_UPDATE_HOME" = "$JDK_FROM_WAS" ]; then
                     IS_WAS_JDK=true
                  fi; 
            else
                ./LogEvent.sh echo "$JDK_UPDATE_HOME does not have $JAVA_SUB_PATH.\n\n
                    ERROR: Cannot use the JDK from the environment.\n\n"
                completedWithError
            fi;
        else
            ./LogEvent.sh echo "No JDK is available from the environment.\n\n"
    
            if [ "$JDK_FROM_WAS" != "" ]; then
                # The WAS JDK, if set, has already been tested.
                ./LogEvent.sh echo "An Application Server JDK is available and will be used.\n\n"
                JDK_UPDATE_HOME=$JDK_FROM_WAS
                IS_WAS_JDK=true
            else        
                ./LogEvent.sh echo "No JDK is available from the Application Server.\n\n
                    ERROR: Unable to determine JDK\n\n"
                completedWithError
            fi
        fi
    else
        ORIG_JDK=$JDK_UPDATE_HOME
    
        while true
        do
            JDK_UPDATE_HOME=$ORIG_JDK
    
            if [ "$JDK_UPDATE_HOME" != "" ]; then
                ./LogEvent.sh echo "A JDK is available from the environment:\n
                    $JDK_UPDATE_HOME\n\n"
        
                GetInput YorN "Use the environment specified JDK [y/n]?" 
                if [ "$YorN" = "yes" ]; then
                    if [ -f "$JDK_UPDATE_HOME/$JAVA_SUB_PATH" ]; then
                        ./LogEvent.sh echo "$JDK_UPDATE_HOME does have $JAVA_SUB_PATH.\n\n
                            Accepting the JDK from the environment.\n\n"
                        break;
                    else
                        ./LogEvent.sh echo "$JDK_UPDATE_HOME does not have $JAVA_SUB_PATH.\n\n
                            The environment JDK cannot be used.\n\n"
                    fi;
                else
                    ./LogEvent.sh echolog "Ignoring the environment specified JDK.\n\n"
                fi;
            else
                ./LogEvent.sh echolog "No JDK is available from the environment.\n\n"
            fi;
    
            if [ "$JDK_FROM_WAS" != "" ]; then
                ./LogEvent.sh echo "A WebSphere Application Server JDK is available:\n
                    $JDK_FROM_WAS.\n\n"
    
                GetInput YorN "Use the Application Server JDK [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    ./LogEvent.sh echo "The Application Server JDK is being used.\n\n"
                    JDK_UPDATE_HOME=$JDK_FROM_WAS
                    IS_WAS_JDK=true
                    break;
                else
                    ./LogEvent.sh echo "Ignoring Application Server JDK.\n\n"
                fi;
            else
                ./LogEvent.sh echo "No Application Server JDK is available.\n\n"
            fi;
    
            ./LogEvent.sh echo "No JDK is available.\n\n"

            GetInput JDK_UPDATE_HOME "Specify the path to the JDK for use:"
            JDK_UPDATE_HOME=$VAR
    
            if [ -f "$JDK_UPDATE_HOME/$JAVA_SUB_PATH" ]; then
                ./LogEvent.sh echolog "$JDK_UPDATE_HOME has $JAVA_SUB_PATH.\n\n
                    Accepting the user specified JDK.\n\n"
                break;
            else
                ./LogEvent.sh echo "$JDK_UPDATE_HOME does not have $JAVA_SUB_PATH.\n\n
                    The user specified JDK cannot be used.\n\n"
            fi;

            GetInput YorN "Cancel this update [y/n]?"
            if [ "$YorN" = "yes" ]; then
                completedWithError
            fi;
        done
    fi;

    ./LogEvent.sh echo "The following JDK home directory will be used:\n
        $JDK_UPDATE_HOME\n"

    if [ "$SKIP_JDK" = "true" ]; then
        ./LogEvent.sh echo "The JDK will not be updated as specified in the\n
            environment ['SKIP_JDK'].\n\n"

        if [ "$SKIP_WAS" = "false" ]; then
            ./LogEvent.sh echo "\n
CAUTION: The WebSphere Application Server is being updated.\n
CAUTION: An update of the JDK used by the Application Server is usually required\n
CAUTION: along with the Application Server update.\n\n"
        fi;

    elif [ "$SILENT" = "true" ]; then
        ./LogEvent.sh echo "Silent Mode: The JDK update will be performed.\n\n"

    else
        if [ "$SKIP_WAS" = "false" ]; then
            ./LogEvent.sh echo "\n
CAUTION: The WebSphere Application Server is being updated.\n
CAUTION: That the JDK be updated is strongly recommended if the selected JDK\n
CAUTION: is used by the Application Server.\n\n"
        fi;

        GetInput YorN "Perform update of the JDK [y/n]?"
        if [ "$YorN" = "yes" ]; then
            ./LogEvent.sh echo "The JDK will be updated per user request.\n\n"
        else
            ./LogEvent.sh echo "The JDK will not be update per user request.\n\n"
            SKIP_JDK=true
        fi;
    fi;
} 

checkIPlanet() {

    # Section for handling dection of iPlanet web server update.
    # Only do this for Solaris and HP-UX because that is all WebSphere 4.0.x support iPlanet on.
    
    # Inputs:
    #     IPLANET_HOME
    #     IPLANET_VERSION
    #
    # Outputs:
    #     IPLANET_HOME
    #     IPLANET_VERSION
    case "$OS_NAME" in
    SunOS|Solaris|HP-UX|AIX)
        ./LogEvent.sh echo "Checking for iPlanet web server update.\n\n"
        
        if [ "$SILENT" = "true" ]; then
        ./LogEvent.sh echo " iPlanet Web Server Support\n
                        WebSphere Application Server 4.0.3 supports the\n
                        iPlanet 4 and iPlanet 6 web servers.\n  
                        The installer will now check if 'IPLANET_HOME' and\n
                        'IPLANET_VERSION' have been set.\n\n"
                        
            if [ "$IPLANET_HOME" = "" ]; then
                ./LogEvent.sh echo "Silent Mode: Update of the iPlanet web server will not occur\n
                                because 'IPLANET_HOME' is null.\n\n"
                IPLANET=
            fi;
            
            if [ "$IPLANET_VERSION" = "" ]; then
                ./LogEvent.sh echo "Silent Mode: Update of the iPlanet web server will not occur\n
                                because 'IPLANET_VERSION' is null.\n\n"
                IPLANET=
            fi;
                
            if [ "$IPLANET_HOME" != "" -a "$IPLANET_VERSION" != "" ]; then
                    ./LogEvent.sh echo "IPLANET_HOME and IPLANET_VERSION are not null.\n
                    The installer will now validate their values.\n\n"

                    if [ ! -f "$IPLANET_HOME/obj.conf" ]; then
                        ./LogEvent.sh echo "ERROR: Silent Mode: The iPlanet web server update is enabled\n
                            but the IPLANET_HOME specified is not a valid directory. [$IPLANET_HOME]\n\n"
                        ./LogEvent.sh echo "No iPlanet configuration update will occur.\n\n"
                        IPLANET=
                    else
                        if [ "$IPLANET_VERSION" = "4" ]; then
                            ./LogEvent.sh echo "The path specified in 'IPLANET_HOME' exists\n
                                and the value specified in 'IPLANET_VERSION' is valid, therefore\n
                                the iPlanet web server configuration update will occur.\n
                                IPLANET_HOME: $IPLANET_HOME\n
                                IPLANET_VERSION: $IPLANET_VERSION\n\n"
                            IPLANET="-iPlanetHome $IPLANET_HOME -iPlanetVersion $IPLANET_VERSION -silent"
                         elif [ "$IPLANET_VERSION" = "6" ]; then
                            if [ "$OS_NAME" = "AIX" ]; then
                                ./LogEvent.sh echo "iPlanet 6 is not supported on AIX.\n
                                Therefore no iPlanet update will occur.\n\n"
                            else
                                ./LogEvent.sh echo "The path specified in 'IPLANET_HOME' exists\n
                                    and the value specified in 'IPLANET_VERSION' is valid, therefore\n
                                    the iPlanet web server configuration update will occur.\n
                                    IPLANET_HOME: $IPLANET_HOME\n
                                    IPLANET_VERSION: $IPLANET_VERSION\n\n"
                                IPLANET="-iPlanetHome $IPLANET_HOME -iPlanetVersion $IPLANET_VERSION -silent"
                            fi;
                         else
                            ./LogEvent.sh echo "The value specified for IPLANET_VERSION\n
                            is not 4 or 6, the value is: $IPLANET_VERSION\n
                            Therefore no iPlanet update will occur.\n\n"
                        fi;
                    fi;
            fi;
        else
            ./LogEvent.sh echo "iPlanet Web Server Support\n
                        WebSphere Application Server 4.0.3 supports the\n
                        iPlanet 4 and iPlanet 6 web servers.\n\n"
	                
            GetInput YorN "Perform update on the iPlanet web server for WebSphere 4.0.3 support [y/n]?"
            if [ "$YorN" = "yes" ]; then
                ORIG_IPLANET=$IPLANET_HOME
                while true
                do
                    IPLANET_HOME=$ORIG_IPLANET
                    if [ "$IPLANET_HOME" != "" ]; then
                        ./LogEvent.sh echo "'IPLANET_HOME' is set to: $IPLANET_HOME\n\n"
                        GetInput YorN "Use this iPlanet configuration path [y/n]?"
                        if [ "$YorN" = "yes" ]; then
                            ./LogEvent.sh echo "The user accepted the path stored in 'IPLANET_HOME'. \n
                            [$IPLANET_HOME]\n\n"
                        else
                            ./LogEvent.sh echo "The user did not accept the iPlanet path \n
                            [$IPLANET_PATH]\n\n"
                            IPLANET_HOME=
                        fi;
                    fi;
                    
                    if [ "$IPLANET_HOME" = "" ]; then
                        GetInput TMP_IPLANET "Enter the iPlanet web server configuration home:\n
                        Example: /usr/iplanet/servers/https-<hostname>/config"
                        TMP_IPLANET=$VAR
                        GetInput YorN "Is this correct [y/n]?"
                        if [ "$YorN" = "yes" ]; then
                            IPLANET_HOME=$TMP_IPLANET
                        else
                            IPLANET_HOME=
                        fi;
                    fi;
                    
                    if [ ! -f "$IPLANET_HOME/obj.conf" ]; then
                        ./LogEvent.sh echo "The path specified in 'IPLANET_HOME' is not a valid directory: \n
                        [$IPLANET_HOME]\n\n"
                        IPLANET_HOME=
                    else
                        ./LogEvent.sh echo "The path specified in 'IPLANET_HOME' is a valid directory:\n
                        [$IPLANET_HOME]\n\n"
                        break;
                    fi;
                    
                    if [ "$IPLANET_HOME" = "" ]; then
                        GetInput YorN "Update the iPlanet web server for WebSphere 4.0.3 support [y/n]?"
                        if [ "$YorN" = "no" ]; then
                            IPLANET_HOME=
                            IPLANET=
                            break;
                        fi;
                    fi;
                done
                
                ORIG_VERSION=$IPLANET_VERSION
                while true
                do 
                IPLANET_VERSION=$ORIG_VERSION
                GetInput IPLANET_VERSION "Please enter the iPlanet version that you have installed.\n
                        Enter either 4 or 6: " 
                        IPLANET_VERSION=$VAR
                        
                        if [ "$IPLANET_VERSION" = "4" -o "$IPLANET_VERSION" = "6" ]; then
                            ./LogEvent.sh echo "IPLANET_VERSION is valid.\n"
                            IPLANET="-iPlanetHome $IPLANET_HOME -iPlanetVersion $IPLANET_VERSION"
                            break;
                        else
                            ./LogEvent.sh echo "IPLANET_VERSION is not valid.\n"
                        fi;
                done
                        
                ./LogEvent.sh echo "The iPlanet web server will be updated per user request.\n\n"
            else
                ./LogEvent.sh echo "Update of iPlanet web server will not occur per user request.\n\n"
                IPLANET=
            fi;    
        fi;
    ;;
    esac
    
}

checkIHS() {

    # Section for handling dection of HTTP server update.
    #
    # Inputs:
    #     INSTALL_IHS
    #     IHS_UPDATE_HOME
    #
    # Outputs:
    #     INSTALL_IHS
    #     IHS_UPDATE_HOME

    ./LogEvent.sh echo "Checking for IBM HTTP Server update.\n\n"

    IHS_CONFIG_FILE=conf/httpd.conf

    if [ "$INSTALL_IHS" = "" ]; then
        INSTALL_IHS=false
    fi;

    if [ "$SILENT" = "true" ]; then
        if [ "$INSTALL_IHS" = "false" ]; then
            ./LogEvent.sh echo "Silent Mode: Update of the IBM HTTP Server is not enabled.\n\n"
        else
            ./LogEvent.sh echo "Update of the IBM HTTP Server is enabled from the environment\n\n"

            if [ "$IHS_UPDATE_HOME" = "" ]; then
                ./LogEvent.sh echo "ERROR: Silent Mode: The IBM HTTP Server update is enabled\n
                    but no IBM HTTP Server Home ['IHS_UPDATE_HOME'] was specified.\n\n"
                completedWithError
            elif [ ! -f "$IHS_UPDATE_HOME/$IHS_CONFIG_FILE" ]; then
                ./LogEvent.sh echo "ERROR: Silent Mode: The IBM HTTP Server update is enabled\n
                    but the specified IBM HTTP Server Home ['IHS_UPDATE_HOME']\n
                    does not have an IHS configuration file.\n\n"
                ./LogEvent.sh echo "The path to the required configuration file is:\n
                    $IHS_UPDATE_HOME/$IHS_CONFIG_FILE\n\n"
                completedWithError
            else
                ./LogEvent.sh echo "The specified IBM HTTP Server Home ['IHS_UPDATE_HOME']
                    has the required IHS configuration file:\n
                    $IHS_UPDATE_HOME/$IHS_CONFIG_FILE\n\n"
            fi;
        fi;
    else
        if [ "$INSTALL_IHS" = "false" ]; then
            ./LogEvent.sh echo "Update of the IBM HTTP Server is not enabled from the\n
                environment.\n\n
                WARNING: If you install the IBM HTTP Server PTF, you may not\n
                WARNING: be able to uninstall it cleanly.  The GSKit package\n
                WARNING: will not be uninstalled.\n\n"

            GetInput YorN "Perform update of the IBM HTTP Server [y/n]?"
            if [ "$YorN" = "no" ]; then
                ./LogEvent.sh echo "Update of the IBM HTTP Server has been disabled by the user.\n\n"
            else
                ./LogEvent.sh echo "Update of the IBM HTTP Server has been enabled by the user.\n\n"
                INSTALL_IHS=true
            fi;
        else
            ./LogEvent.sh echo "Update of the IBM HTTP Server has been enabled from the environment.\n\n"
        fi;

        if [ "$INSTALL_IHS" = "true" ]; then
            ORIG_IHS=$IHS_UPDATE_HOME

            while true
            do
                IHS_UPDATE_HOME=$ORIG_IHS

                if [ "$IHS_UPDATE_HOME" != "" ]; then
                    ./LogEvent.sh echo "An IBM HTTP Server home has been specified on the environment:\n
                        $IHS_UPDATE_HOME\n\n"
    
                    GetInput YorN "Use this IBM HTTP Server home [y/n]?"
                       if [ "$YorN" = "yes" ]; then
                        ./LogEvent.sh echo "Accepting the environment specified IBM HTTP Server home.\n\n"
                    else
                        ./LogEvent.sh echo "Ignoring the environment IBM HTTP Server home.\n\n"
                        IHS_UPDATE_HOME=
                    fi;
                fi;

                if [ "$IHS_UPDATE_HOME" = "" ]; then
                    GetInput Default "Enter the IBM HTTP Server home:[$DEFAULT_IHS_DIR]" "$DEFAULT_IHS_DIR"
                    IHS_UPDATE_HOME=$VAR
                fi;

                if [ ! -f "$IHS_UPDATE_HOME/$IHS_CONFIG_FILE" ]; then
                    ./LogEvent.sh echo "The IBM HTTP Server home does not contain a required configuration file:\n
                        $IHS_UPDATE_HOME/$IHS_CONFIG_FILE\n\n"

                    GetInput YorN "Cancel this update [y/n]?"
                    if [ "$YorN" = "yes" ]; then
                        completedWithError
                    fi;
                else
                    ./LogEvent.sh echo "The IBM HTTP Server home contains the required a configuration file.\n
                        $IHS_UPDATE_HOME/$IHS_CONFIG_FILE \n\n"
                    break;
                fi;
            done
        fi;
    fi;
}

checkJ2C() {
    # Section for handling detection of J2C update.

    # Inputs:
    #     SILENT
    #     JDK_UPDATE_HOME
    #     IS_WAS_JDK
    #     FORCEJ2C
    #
    # Outputs:
    #     INSTALL_J2C
    #     UPDATE_J2C

    ./LogEvent.sh echo "Testing for update of the J2C Connector Architecture.\n\n"

    if [ ! -f "J2Cinstaller.jar" ]; then
        ./LogEvent.sh echo "No J2C Update is available within this FixPack.\n\n"
        INSTALL_J2C=false
        UPDATE_J2C=false

    elif [ "$IS_WAS_JDK" = "false" ]; then
        ./LogEvent.sh echo "The JDK specified in use is not the Application Server JDK.\n
            The J2C update will not be performed.\n\n"
        INSTALL_J2C=false
        UPDATE_J2C=false

    elif [ -f "$JDK_UPDATE_HOME/lib/j2c.jar" ]; then
        ./LogEvent.sh echo "A J2C jar is present in the target JDK home.  An update\n
            will be performed.\n\n"
        INSTALL_J2C=false
        UPDATE_J2C=true

    else
        ./LogEvent.sh echo "The Connector Architecture [J2C] jar file is not present:
            $JDK_UPDATE_HOME/lib/j2c.jar\n\n"

        if [ "$FORCEJ2C" = "true" ]; then
            ./LogEvent.sh echo "The installation of the Connector Architecture [J2C] has\n
                been forced from the environment [FORCEJ2C].\n\n"
            INSTALL_J2C=true
            UPDATE_J2C=false
        else
            ./LogEvent.sh echo "The Connector Architecture [J2C] installation has not been\n
                forced by the environment [FORCEJ2C].\n\n"

            if [ "$SILENT" = "true" ]; then
                ./LogEvent.sh echo "Silent Mode: Skipping update of Connector Architecture [J2C].\n\n"
                INSTALL_J2C=false
            else
                ./LogEvent.sh echo "The Connector Architecture for WebSphere [J2C] is not present in\n
                    the specified installation.\n\n
                    The Connector Architecture for WebSphere [J2C] was delivered in\n
                    WebSphere Advanced Edition, release 4.0 as a technology preview.\n
                    This initial delivery was based upon the J2EE 1.3 specification,\n
                    which had not yet been released by Sun.  The specification has been\n
                    made generally available by Sun.  The Connector Architecture for\n
                    WebSphere is now available and may be installed by this update.\n\n"

                GetInput YorN "Install Connector Architecture for WebSphere [J2C] [y/n]?" 
                if [ "$YorN" = "yes" ]; then
                    ./LogEvent.sh echo "By user request, the Connector Architecture [J2C] will be installed.\n\n"
                    INSTALL_J2C=true
                    UPDATE_J2C=false
                else
                    ./LogEvent.sh echo "By user request, the Connector Architecture [J2C] will not be installed.\n\n"
                    INSTALL_J2C=false
                    UPDATE_J2C=false
                fi;
            fi;
        fi;
    fi;
}

checkLogs() {

    # Inputs:
    #     SILENT
    #     LOGS_DIR
    #     SKIP_WAS
    #     WAS_UPDATE_HOME
    #     TMP
    #
    # Outputs:
    #     LOGS_DIR
    #     LEAVE_LOGS

    ./LogEvent.sh echolog "Determining location for log files, including the\n
        final location for the summary log file.\n\n"

    # ./LogEvent.sh echo "Log files are usually placed under the WebSphere Application"
    # ./LogEvent.sh echo "server home.  However, log files may also be placed in the"
    # ./LogEvent.sh echo "following locations:"
    # ./LogEvent.sh echo ""
    # ./LogEvent.sh echo "* In a directory specified through the environment ['LOGS_DIR']"
    # ./LogEvent.sh echo "* In the temporary directory ['TMP']"
    # ./LogEvent.sh echo "* In the current directory"
    # ./LogEvent.sh echo "* In a user specified directory"
    # ./LogEvent.sh echo ""
    # ./LogEvent.sh echo "Unless logs are placed in the temporary directory, the summary"
    # ./LogEvent.sh echo "log will be copied into the logs directory at the end of"
    # ./LogEvent.sh echo "update processing."
    # ./LogEvent.sh echo ""

    LEAVE_LOG=false

    if [ "$SILENT" = "true" ]; then
        if [ "$LOGS_DIR" != "" ]; then
            ./LogEvent.sh echo "A logs directory has been set in the environment:\n
                $LOGS_DIR\n\n
                Testing that the logs directory from the environment is writable.\n\n"

            echo "Testing" > "$LOGS_DIR/ZZXRM.tmp" >/dev/null 2>&1

            if [ -f "$LOGS_DIR/ZZXRM.tmp" ]; then
                rm "$LOGS_DIR/ZZXRM.tmp"
                ./LogEvent.sh echolog "The logs directory is writable.\n\n
                    Accepting the logs directory from the environment.\n\n"
            else
                ./LogEvent.sh echo "ERROR: The specified directory is not writable.\n\n"
                completedWithError
            fi
        else
            ./LogEvent.sh echo "No logs directory was set in the environment [LOGS_DIR].\n\n"

            if [ "$SKIP_WAS" = "false" ]; then
                LOGS_DIR=$WAS_UPDATE_HOME/logs
                ./LogEvent.sh echo "The logs, including the summary log file, will be\n
                    put in the WebSphere Application Server logs directory:\n
                    $LOGS_DIR\n\n"
            else
                LOGS_DIR=$TMP
                LEAVE_LOG=true
                ./LogEvent.sh echo "The Application Server is not being updated.\n\n
                    The WebSphere Application server logs directory cannot be\n
                    automatically used.\n\n
                    Logs will be placed in the temporary directory: $TMP\n\n"
            fi
        fi
    else
        LOGS_ORIG=$LOGS_DIR

        while true
        do
            LOGS_DIR=$LOGS_ORIG
    
            if [ "$LOGS_DIR" != "" ]; then
                ./LogEvent.sh echo "A logs directory is specified in the environment:\n
                    $LOGS_DIR\n\n"

                GetInput YorN "Use the environment logs directory [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    ./LogEvent.sh echo "Testing that the environment logs directory is writable.\n\n"

                    echo "Testing" > "$LOGS_DIR/ZZXRM.tmp" >/dev/null 2>&1
                    if [ ! -f "$LOGS_DIR/ZZXRM.tmp" ]; then
                        rm "$LOGS_DIR/ZZXRM.tmp"
                        ./LogEvent.sh echolog "The environment logs directory is writable.\n\n
                            Accepting the environtment logs directory for use.\n\n"
                        break;
                    else
                        ./LogEvent.sh echo "ERROR: The environment logs directory is not writable.\n\n"
                    fi;
                else
                    ./LogEvent.sh echo "Ignoring the environment specified logs directory.\n\n"
                fi;
            fi;

            if [ "$SKIP_WAS" = "false" ]; then
                ./LogEvent.sh echo "The WebSphere Application server will be updated.\n\n"
    
                GetInput YorN "Use the Application Server Logs directory [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    LOGS_DIR=$WAS_UPDATE_HOME/logs
                    ./LogEvent.sh echo "Using the Application Server Logs directory:\n
                        $LOGS_DIR\n\n"
                    break;
                else
                    ./LogEvent.sh echo "Bypassing the Application Server Logs directory.\n\n"
                fi;
            else
                ./LogEvent.sh echo "The WebSphere Application server is not being updated.\n
                    The WebSphere Application server logs directory cannot be\n
                    automatically used.\n\n"
            fi;

            GetInput YorN "Put logs in the temporary directory [y/n]?"
            if [ "$YorN" = "yes" ]; then
                ./LogEvent.sh echo "Logs will be put in the temporary directory.\n\n"
                LOGS_DIR=$TMP
                LEAVE_LOG=true
        break;
            fi;

            GetInput YorN "Put logs in the current directory [y/n]?"
            if [ "$YorN" = "yes" ]; then
                ./LogEvent.sh echolog "Testing that the current directory is writable.\n\n"

                echo "Testing" > "./ZZXRM.tmp" >/dev/null 2>&1
                if [ -f "./ZZXRM.tmp" ]; then
                    rm "./ZZXRM.tmp"
                    ./LogEvent.sh echolog "The current directory is writable.\n\n
                        Logs will be put in the current directory.\n\n"
                    LOGS_DIR="."
                    LEAVE_LOG=false
                    break;
                else
                    ./LogEvent.sh echo "The current directory is not writable.\n\n"
                fi
            fi

            GetInput YorN "Put logs in a user specified directory [y/n]?"
            if [ "$YorN" = "yes" ]; then
                GetInput LOGS_DIR "What directory should be used for logs:"
                LOGS_DIR=$VAR
        
                ./LogEvent.sh echolog "Testing that the specified logs directory is writable.\n\n"
    
                echo "Testing" > "$LOGS_DIR/ZZXRM.tmp" >/dev/null 2>&1
    
                if [ -f "$LOGS_DIR/ZZXRM.tmp" ]; then
                    rm "$LOGS_DIR/ZZXRM.tmp"
                    ./LogEvent.sh echolog "The specified logs directory is writable.\n\n
                        Logs will be put in the directory:\n
                        $LOGS_DIR\n\n"
                    LEAVE_LOG=false
                    break
                fi
            else
                ./LogEvent.sh echo "ERROR: The logs directory is not writable.\n\n"
            fi

            GetInput YorN "Cancel this update [y/n]?"
            if [ "$YorN" = "yes" ]; then
                completedWithError
            fi
        done
    fi
}

checkBackup() {

    # Section for determine where to put backup files.
    #
    # Inputs:
    #     SILENT
    #     BACKUP_DIR
    #     SKIP_WAS
    #     WAS_UPDATE_HOME
    #
    # Outputs:
    #    BACKUP_DIR

    ./LogEvent.sh echo "Determining the location for backup files.\n\n"

    # ./LogEvent.sh echo "Backup files may be placed in any of the"
    # ./LogEvent.sh echo "following locations:"
    # ./LogEvent.sh echo "* In a location specified in the environment ['BACKUP_DIR']"
    # ./LogEvent.sh echo "* In the WebSphere Application Server Home"
    # ./LogEvent.sh echo "* In the current directory."
    # ./LogEvent.sh echo "* In a user specified directory."
    # ./LogEvent.sh echo "* In the temporary directory ['TMP']."
    # ./LogEvent.sh echo ""
    # ./LogEvent.sh echo "Typically, backup files are placed under the"
    # ./LogEvent.sh echo "WebSphere Application Server Home."
    # ./LogEvent.sh echo ""
    # ./LogEvent.sh echo "The update has particular requirements for the amount of"
    # ./LogEvent.sh echo "required for backup files.  Ensure that sufficient space"
    # ./LogEvent.sh echo "is available for backup files."
    # ./LogEvent.sh echo ""


    if [ "$SILENT" = "true" ]; then
        if [ "$BACKUP_DIR" != "" ]; then
            ./LogEvent.sh echo "A directory for backup files has been specified in the environment:\n
                $BACKUP_DIR\n\n"

            ./LogEvent.sh echo "Testing the writability of the backup directory.\n\n"

            echo "Testing" > "$BACKUP_DIR/ZZXRM.tmp" >/dev/null 2>&1

            if [ -f "$BACKUP_DIR/ZZXRM.tmp" ]; then
                rm "$BACKUP_DIR/ZZXRM.tmp"
                ./LogEvent.sh echolog "The backup directory is writable.\n\n
                    Backups will be placed in the specified directory.\n\n"
            else
                ./LogEvent.sh echo "ERROR: The environment set backup directory [BACKUP_DIR]\n
                    ERROR: is not writable.\n\n"
                completedWithError
            fi
        else
            ./LogEvent.sh echo "No environment set backup directory is available.\n\n"

            if [ "$SKIP_WAS" = "false" ]; then
                BACKUP_DIR=$WAS_UPDATE_HOME
                ./LogEvent.sh echo "The WebSphere Application Server is being updated.\n\n
                    Backups will be placed in the Application Server home:\n
                    $BACKUP_DIR\n\n"
            else
                ./LogEvent.sh echo "The Application server is not being updated.\n\n
                    Testing the writability of the current directory.\n\n"

                echo "Testing" > "./ZZXRM.tmp" >/dev/null 2>&1
                if [ -f "./ZZXRM.tmp" ]; then
                    rm "./ZZXRM.tmp"
                    BACKUP_DIR=.
                    ./LogEvent.sh echo "The current directory is writable.\n\n
                        Backups will be placed in the current directory.\n\n"
                else
                    ./LogEvent.sh echo "The current directory is not writable.\n\n
                        Backups will be written to the temporary directory [TMP]:\n
                        $TMP\n\n"
                    BACKUP_DIR=$TMP
                fi;
            fi;
        fi;
    else
        ORIG_BACKUP=$BACKUP_DIR
        while true
        do
            BACKUP_DIR=$ORIG_BACKUP

            if [ "$BACKUP_DIR" != "" ]; then
            ./LogEvent.sh echo "A directory for backup files has been specified\n
                    \in the environment:\n
                    $BACKUP_DIR\n\n"

                GetInput YorN "Use the environment specified backup directory [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    ./LogEvent.sh echo "Testing the writability of the backup directory.\n\n"

                    echo "Testing" > "$BACKUP_DIR/ZZXRM.tmp" >/dev/null 2>&1

                    if [ -f "$BACKUP_DIR/ZZXRM.tmp" ]; then
                        rm "$BACKUP_DIR/ZZXRM.tmp"
                        ./LogEvent.sh echo "The backup directory is writable and has been\n
                            accepted for use.\n\n"
                        break;
                    else
                        ./LogEvent.sh echo "ERROR: The backup directory set in the environment is not writable.\n\n"
                    fi;
                else
                    ./LogEvent.sh echo "Ignoring the backup directory set in the environment.\n\n"
                fi;
            else
                ./LogEvent.sh echo "No backup directory is set in the environment.\n\n"
            fi;

            if [ "$SKIP_WAS" = "false" ]; then
                ./LogEvent.sh echo "A WebSphere Application server home is set:\n
                    $WAS_UPDATE_HOME\n\n"

                GetInput YorN "Place backups under the WebSphere Application Server Home [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    BACKUP_DIR=$WAS_UPDATE_HOME
                    ./LogEvent.sh echo "Backups will be placed under the WebSphere Application Server Home.\n\n"
                    break;
                else
                    ./LogEvent.sh echo "The WebSphere Application server home will not be used for backups.\n\n"
                fi;
            fi;

            GetInput YorN "Place backups under the current directory [y/n]?"
            if [ "$YorN" = "yes" ]; then
                ./LogEvent.sh echo "Testing the writability of the current directory.\n\n"

                echo "Testing" > "./ZZXRM.tmp" >/dev/null 2>&1
                if [ -f "./ZZXRM.tmp" ]; then
                    rm "./ZZXRM.tmp"
                    BACKUP_DIR="$PWD"
                    BACKUP_COMPLETE=true
                    ./LogEvent.sh echo "The current directory is writable.\n\n
                        Backups will be placed under the current directory.\n\n"
            break;
                else
                    ./LogEvent.sh echo "The current directory is not writable.\n\n"
                fi;
            fi;

            if [ "$TMP" != "." ]; then
                ./LogEvent.sh echo "The temporary directory is set to: $TMP \n\n"

                GetInput YorN "Place backups under the temporary directory [y/n]?"
                if [ "$YorN" = "yes" ]; then
                    BACKUP_DIR=$TMP
                    ./LogEvent.sh echo "Backups will be placed in the temporary directory.\n\n"
                    break;
                fi;
            fi;

            GetInput YorN "Specify a directory for backups [y/n]?"
            if [ "$YorN" = "yes" ]; then
                GetInput BACKUP_DIR "Specify the directory for backups:"
                BACKUP_DIR=$VAR
                ./LogEvent.sh echolog "Testing the writability of the specified directory.\n\n"
    
                echo "Testing" > "$BACKUP_DIR/ZZXRM.tmp" >/dev/null 2>&1
    
                if [ -f "$BACKUP_DIR/ZZXRM.tmp" ]; then
                    rm "$BACKUP_DIR/ZZXRM.tmp"
                    ./LogEvent.sh echo "The specified directory is writable.\n\n
                        Backups will be placed in the specified directory.\n\n"
            break;
                else
                    ./LogEvent.sh echo "The specified backup directory is not writable.\n\n"
                fi;
            fi;

            GetInput YorN "Cancel this update [y/n]?"
            if [ "$YorN" = "yes" ]; then
                completedWithError
            fi;
        done
    fi;

    if [ "$BACKUP_DIR" != "." ]; then
        ./LogEvent.sh echo "Copying helper files."
        cp ./LogEvent.sh "$BACKUP_DIR"
        cp ./uninstall_"$PTFNUM".sh "$BACKUP_DIR"
        ./LogEvent.sh echo "Copying helper files -- Done.\n\n"
    else
        ./LogEvent.sh echo "The backup directory is the same as the current directory."
        ./LogEvent.sh echo "Copies of helper files do not need to be made.\n\n"        
    fi
}

updateError() {
    ./LogEvent.sh echo "Update Error Report:\n\n
            Section Name: $SectionName\n
            Command Name: $CommandName\n
            Command Description: $CommandDescription\n\n
            Command Log File: $CommandLog\n
            Command Backup File: $CommandBackup\n\n"

    copyLog

    ./LogEvent.sh echo "Please run $WAS_UPDATE_HOME/uninstall_$PTFNUM.sh to backout the changes\n"

    if [ "$OS_NAME" = "AIX" ]; then
        ./LogEvent.sh slibclean
    fi;

    completedWithError
}

updateWAS() {
    SectionName=UpdateApplicationServer

    CommandName=ExecuteApplication
    CommandName=ExecuteApplicationServerUpdate
    CommandDescription="Run java on the supplied application server update jar file."
    CommandBackup=$BACKUP_DIR/was40_${Edition}_${PTFNUM}_backup.jar
    CommandLog=$LOGS_DIR/was40_${Edition}_$PTFNUM.log

    ./LogEvent.sh echo "Executing update from jar file: was40_${Edition}_$PTFNUM.jar\n
        Executing update against target: $WAS_UPDATE_HOME\n
        Creating backup jar file: $CommandBackup\n
        Creating update log file: $CommandLog\n\n"

    ./LogEvent.sh echo $JDK_UPDATE_HOME/jre/bin/java -jar was40_${Edition}_$PTFNUM.jar -target "$WAS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -TmpDir "$TMP" $OverWriteBUJ $IPLANET

    $JDK_UPDATE_HOME/jre/bin/java -jar was40_${Edition}_$PTFNUM.jar -target "$WAS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -TmpDir "$TMP" $OverWriteBUJ $IPLANET
    RC=$?
    ./LogEvent.sh echo "Completed WAS PTF Install with RC=$RC"

    if [ $RC -ne 0 ]; then
        ./LogEvent.sh echo "An error occurred during the WebSphere Application Server update\n\n"
        updateError
    fi;
}

updateJDK() {
    SectionName=UpdateJDK

    ./LogEvent.sh echo "Creating working copy of the JDK:\n
        Source JDK Path: $JDK_UPDATE_HOME\n
        Target JDK Path: $TMP/java_$PTFNUM\n\n"

    if [ -d "$TMP/java_$PTFNUM" -o -f "$TMP/java_$PTFNUM" ]; then

        CommandName=RemoveStaleJDK
        CommandDescription="Remove a stale working copy of the JDK."
        CommandBackup="None is available"
        CommandLog="None is available"

        ./LogEvent.sh echo "Removing a stale copy of the JDK.\n\n"

        ./LogEvent.sh rm -r $TMP/java_$PTFNUM
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while removing a stale copy of the JDK.\n\n"
            updateError
        fi;
    fi;
    CommandName=CreateJDKCopyDir
    CommandDescription="Create a directory for a working copy of the JDK."
    CommandBackup="None is available"
    CommandLog="None is available"

    ./LogEvent.sh echo "Creating working directory for the JDK\n"

    ./LogEvent.sh mkdir $TMP/java_$PTFNUM
    if [ $? -ne 0 ]; then
        ./LogEvent.sh echo "An error occurred while creating a working directory for the JDK update.\n\n"
        updateError
    fi;
   
    CommandName=CopyJDKForWork
    CommandDescription="Create a working copy of the JDK before applying the JDK update."
    CommandBackup="None is available"
    CommandLog="None is available"

    ./LogEvent.sh echo "Copying JDK into working directory.\n"

    if [ "$OS_NAME" = "Linux" ] ; then
        ./LogEvent.sh cp -Rfd $JDK_UPDATE_HOME/* $TMP/java_$PTFNUM/
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while copying the JDK.\n\n"
            updateError
        fi;
    else
        ./LogEvent.sh cp -R $JDK_UPDATE_HOME/* $TMP/java_$PTFNUM/
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while copying the JDK.\n\n"
            updateError
        fi;
    fi

    CommandName=ExecuteJDKUpdate
    CommandDescription="Run java on the supplied JDK update jar file."
    CommandBackup=$BACKUP_DIR/jdk_${PTFNUM}_backup.jar
    CommandLog=$LOGS_DIR/jdk_$PTFNUM.log

    ./LogEvent.sh echo "Executing update from jar file: \n
        jdk_$PTFNUM.jar\n
        Executing update against target:\n
        $WAS_UPDATE_HOME/java_$PTFNUM\n
        Creating backup jar file:\n
        $CommandBackup\n
        Creating update log file:\n
        $CommandLog\n\n"

    # --- Echo a hyperlink from the summary log file to the detail log file.

    ./LogEvent.sh echo $JDK_UPDATE_HOME/jre/bin/java -jar jdk_$PTFNUM.jar -target "$TMP/java_$PTFNUM" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ

    $JDK_UPDATE_HOME/jre/bin/java -jar jdk_$PTFNUM.jar -target "$TMP/java_$PTFNUM" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ
    RC=$?
    ./LogEvent.sh echo "Completed JDK Upgrade of Working copy with RC=$RC"

    if [ $RC -ne 0 ]; then
        ./LogEvent.sh echo "An error occurred during the JDK update.\n\n"

        CommandName=RemoveWorkJDK
        CommandDescription="Removing the working copy of the JDK."
        CommandBackup="None is available"
        CommandLog="None is available"

        ./LogEvent.sh rm -rf $TMP/java_$PTFNUM

        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while removing the working copy of the JDK.\n\n"
        fi;
        updateError
    else
        CommandName=PlaceUpdatedJDK
        CommandDescription="Placing the update JDK."
        CommandBackup="None is available"
        CommandLog="None is available"

        ./LogEvent.sh echo "Updating JDK. Please wait ...\n"
        sleep 5
        ./LogEvent.sh echo "Removing old code from java home"
        ./LogEvent.sh rm -rf $JDK_UPDATE_HOME/*

        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while removing the old copy of the JDK.\n\n"
            updateError
        fi;


        if [ "$OS_NAME" = "Linux" ] ; then
            ./LogEvent.sh cp -Rfd $TMP/java_$PTFNUM/* $JDK_UPDATE_HOME/
            if [ $? -ne 0 ]; then
                ./LogEvent.sh echo "An error occurred while placing the updated copy of the JDK."
                updateError
            fi;
        else
            ./LogEvent.sh cp -R $TMP/java_$PTFNUM/* $JDK_UPDATE_HOME/
            if [ $? -ne 0 ]; then
                ./LogEvent.sh echo "An error occurred while placing the updated copy of the JDK."
                updateError
            fi;
        fi;

        ./LogEvent.sh echo "Successfully placed the updated JDK.\n\n
            Removing the working copy of the JDK.\n
            Target JDK Path: $TMP/java_$PTFNUM\n\n"

        CommandName=RemoveWorkJDK
        CommandDescription="Removing the working copy of the JDK."
        CommandBackup="None is available"
        CommandLog="None is available"

        ./LogEvent.sh rm -rf $TMP/java_$PTFNUM
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while removing the working copy of the JDK."
            updateError
        fi;

        # OS specific JDK permission updates.
        # This really ought to be done by the extractor,
        # but that feature hasn't been added yet.

        case "$OS_NAME" in
        HP-UX)
            ./LogEvent.sh chmod -R 755 $JDK_UPDATE_HOME/jre/lib/PA_RISC/*
            ./LogEvent.sh chmod -R 755 $JDK_UPDATE_HOME/jre/lib/PA_RISC2.0/*
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/jre/bin/.start_xfs
		./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/jre/bin/*
		./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/bin/*
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/bin/.start_xfs
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/bin/PA_RISC/native_threads/.start_xfs
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/bin/PA_RISC2.0/native_threads/.start_xfs
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/jre/bin/PA_RISC/native_threads/.start_xfs
            ./LogEvent.sh chmod 755 $JDK_UPDATE_HOME/jre/bin/PA_RISC2.0/native_threads/.start_xfs
        ;;
        SunOS|Solaris)
            ./LogEvent.sh chmod -R 755 $JDK_UPDATE_HOME/jre/lib/sparc/*
        ;;
        *)
        ;;
        esac
    fi;
}

updateIHS() {
     SectionName=UpdateIHS

    ./LogEvent.sh echo "Performing the base IHS update.\n\n"

     CommandName=ExecuteIHSUpdate
     CommandDescription="Run java on the supplied IHS update jar file."
     CommandBackup=$BACKUP_DIR/ihs_${PTFNUM}_backup.jar
     CommandLog=$LOGS_DIR/ihs_$PTFNUM.log

     ./LogEvent.sh echo "Executing update from jar file:\n
        ihs_$PTFNUM.jar\n
        Executing update against target:\n
        $IHS_UPDATE_HOME\n
        Creating backup jar file:\n
        $CommandBackup\n
        Creating update log file:\n
        $CommandLog\n\n"

     # --- Echo a hyperlink from the summary log file to the detail log file.

     ./LogEvent.sh echo $JDK_UPDATE_HOME/jre/bin/java -jar ihs_$PTFNUM.jar -target "$IHS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ

     $JDK_UPDATE_HOME/jre/bin/java -jar ihs_$PTFNUM.jar -target "$IHS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ
     RC=$?
     ./LogEvent.sh echo "Completed IHS Upgrade with RC=$RC"


    if [ $RC -ne 0 ]; then
        ./LogEvent.sh echo "An error occurred during the base IHS update.\n"
        updateError
    else
        ./LogEvent.sh echo "The base IHS update was successful.\n"
    fi;


    ./LogEvent.sh echo "Updating GSKIT.\n\n"

    CommandName=ExecuteGSkitUpdate
    CommandDescription="Execute the IHS supplied GSK setup program."
    CommandBackup="None is available"
    CommandLog="None is available"

    case "$OS_NAME" in
    AIX)
        ./LogEvent.sh echo "Installing new version of GSkit."
        ./LogEvent.sh installp -acgXd $IHS_UPDATE_HOME all
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing installp for GSKit update.\n\n"
            updateError
        else
            ./LogEvent.sh echo "The update of GSKit was successful.\n\n"
        fi;
       ;;
    SunOS|Solaris)
        ./LogEvent.sh echo "Installing new version of GSkit.\n\n"
        ./LogEvent.sh pkgadd -a admin -d $IHS_UPDATE_HOME all
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing pkgadd for GSKit update.\n\n"
            updateError
        else
            ./LogEvent.sh echo "The update of GSKit was successful.\n\n"
        fi;
       ;;
    HP-UX)
        ./LogEvent.sh echo "Uninstalling previous version of GSkit.\n\n"
        ./LogEvent.sh /usr/sbin/swremove -x autoselect_dependents=false -x enforce_dependencies=false gsk5bas
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred while uninstalling previous GSKit version.\n\n"
            updateError
        else
            ./LogEvent.sh echo "The uninstall of previous version of GSKit was successful.\n\n"
        fi;

        ./LogEvent.sh echo "Installing new version of GSkit.\n\n"

        ./LogEvent.sh /usr/bin/chmod u+x $IHS_UPDATE_HOME/gsk5bas/catalog/gsk5bas/gsk5bas/postinstall
        ./LogEvent.sh /usr/bin/chmod u+x $IHS_UPDATE_HOME/gsk5bas/catalog/gsk5bas/gsk5bas/preremove
        ./LogEvent.sh /usr/sbin/swreg -l depot $IHS_UPDATE_HOME/gsk5bas

        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing swreg for GSKit update.\n\n"
            updateError

        fi;

        ./LogEvent.sh /usr/sbin/swinstall -s $IHS_UPDATE_HOME/gsk5bas gsk5bas

        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing swinstall for GSKit update.\n\n"
            updateError
        else
            ./LogEvent.sh echo "The update of GSKit was successful.\n\n"
        fi;
    ;;
    Linux)
        ./LogEvent.sh echo "Upgrading GSkit.\n\n"

        ./LogEvent.sh rpm --nodeps -ev gsk5bas-5.0-3.61
        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing rpm --nodeps for GSKit update.\n\n"
            updateError
        fi;

        ./LogEvent.sh rpm -Uvh $IHS_UPDATE_HOME/gsk5bas*.rpm

        if [ $? -ne 0 ]; then
            ./LogEvent.sh echo "An error occurred doing rpm for GSKit update.\n\n"
            updateError
        else
            ./LogEvent.sh echo "The update of GSKit was successful.\n\n"
        fi;
    ;;
    esac
}

## Need to document what is going on with this particular update.

skipUpdateIHS() {
    case "$OS_NAME" in
        SunOS|Solaris)
            #if IHS is not upgraded and OS is SUN then install GSKIT4
            # extract GSKIT4 from IHS PTF

            ./LogEvent.sh echo "Installing GSKIT4 since IHS upgrade was not selected.\n\n"

            ./LogEvent.sh $JDK_UPDATE_HOME/bin/jar -xvf ihs_$PTFNUM.jar /gsk4bas
            if [ $? -ne 0 ]; then
                ./LogEvent.sh echo "Failed to install GSKIT4 \n\n"
                failedGskit4=true
            else
                failedGskit4=false
            fi;

            # install package
            ./LogEvent.sh pkgadd -a admin -d / gsk4bas

            if [ $? -ne 0 ]; then
                ./LogEvent.sh echo "Failed to install GSKIT4 \n\n"
                failedGskit4=true
            else
                failedGskit4=false
            fi;

            ./LogEvent.sh rm -fR /gsk4bas

            if [ "$failedGskit4" = "false" ]; then
                ./LogEvent.sh echo "GSKIT4 was successfully installed.\n\n"
            fi
            ;;
        *)
        ;;
    esac
}


updateJ2C() {
    CommandName=RunJ2CUpdate
    CommandDescription="Run java on the supplied J2C update jar file."

    CommandBackup=$BACKUP_DIR/J2C_${PTFNUM}_backup.jar
    CommandLog=$LOGS_DIR/J2C_$PTFNUM.log

    ./LogEvent.sh echo "Executing update from jar file:\n
        J2Cinstaller.jar\n
        Executing update against target:\n
        $WAS_UPDATE_HOME\n
        Creating backup jar file:\n
        $CommandBackup\n
        Creating update log file:\n
        $CommandLog\n\n"

    # --- Echo a hyperlink from the summary log file to the detail log file.

    ./LogEvent.sh echo "$JDK_UPDATE_HOME/jre/bin/java" -jar J2Cinstaller.jar -target "$WAS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ

    $JDK_UPDATE_HOME/jre/bin/java -jar J2Cinstaller.jar -target "$WAS_UPDATE_HOME" -backupJar "$CommandBackup" -log "$CommandLog" -SkipVer -TmpDir "$TMP" $OverWriteBUJ
    if [ $? -ne 0 ]; then
        ./LogEvent.sh echo "An error occurred during the J2C Connector install/update.\n"
        updateError
    fi;
}

performUpdates() {
    ./LogEvent.sh echo "About to perform selected updates\n"

    if [ "$OS_NAME" = "AIX" ]; then
        ./LogEvent.sh slibclean
    fi

    if [ "$SKIP_WAS" = "true" ]; then 
        ./LogEvent.sh echo "The update of the WebSphere Application Server was disabled.\n"
        else
        ./LogEvent.sh echo "Updating the WebSphere Application Server\n"
        updateWAS
        ./LogEvent.sh echo "The update of the WebSphere Application Server was successful.\n\n"
    fi;

    if [ "$SKIP_JDK" = "true" ]; then 
        ./LogEvent.sh echo "The update of the Java Development Kit was disabled.\n"
        else
        ./LogEvent.sh echo "Updating the Java Development Kit.\n\n"
        updateJDK
        ./LogEvent.sh echo "The update of Java Development Kit was successful.\n"
    fi;

    if [ "$INSTALL_IHS" = "false" ]; then 
        ./LogEvent.sh echo "The update of the IHS was disabled.\n"
        skipUpdateIHS
        else
        ./LogEvent.sh echo "Performing the IBM HTTP Server update.\n\n"
        updateIHS
        ./LogEvent.sh echo "The IBM HTTP Server update was successful.\n\n"
    fi;

    if [ "$INSTALL_J2C" = "true" ]; then
        ./LogEvent.sh echo "Installing J2C Connector\n"
        updateJ2C
        ./LogEvent.sh echo "The installation of the J2C Connector was successful.\n\n"
    elif [ "$UPDATE_J2C" = "true" ]; then 
        ./LogEvent.sh echo "Updating J2C Connector\n"
        updateJ2C
        ./LogEvent.sh echo "The update of the J2C Connector was successful.\n\n"
    fi;    
}

###############################################
#    MAIN STARTS HERE
###############################################

if [ "$1" = "-usage" -o "$1" = "-Usage" ]; then
    usage
fi;
if [ "$1" = "-help" -o "$1" = "-Help" ]; then
    help
fi;
if [ "$1" != "-silent" -a "$1" != "-Silent" ]; then
   checkLicense
fi;

testTools
forceTmp
testTmp
writeSummaryHeader
initOS
parseOptions $*
checkUpdateJars
checkUpdateWas
checkJDK
checkIPlanet
checkIHS
#checkJ2C
checkLogs
checkBackup
performUpdates
completeInstall
